/*
 * Copyright(C) Seiko Epson Corporation 2016. All rights reserved.
 *
 * Warranty Disclaimers.
 * You acknowledge and agree that the use of the software is at your own risk.
 * The software is provided "as is" and without any warranty of any kind.
 * Epson and its licensors do not and cannot warrant the performance or results
 * you may obtain by using the software.
 * Epson and its licensors make no warranties, express or implied, as to non-infringement,
 * merchantability or fitness for any particular purpose.
 */

package nmd.emd.epson.com.probt_2000bluetooth;

import android.app.Activity;
import android.bluetooth.BluetoothAdapter;
import android.content.Intent;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

public class BeaconActivity extends Activity {

    public static final String COM_EXAMPLE_BLEBEACON = "com.example.blebeacon";
    private Button btnSave;
    private EditText edtBeacon1, edtLocation;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_beacon);

        //Assign UI widgets objects
        btnSave = (Button) findViewById(R.id.btnSave);

        edtBeacon1 = (EditText) findViewById(R.id.edtBeacon1);

        edtLocation = (EditText) findViewById(R.id.edtLocation);

        btnSave.setEnabled(false);


        //Add event code to detect when beacon text field is exited
        setOnLeaveEdtBeacon(edtBeacon1);
    }


    /**
     * Launch EPSON Application for displaying the Beacons
     * @param view
     */
    public void OnClickBleBeaconApp(View view) {

        Toast.makeText(this, R.string.moving_external_app, Toast.LENGTH_LONG).show();

        Intent launchIntent = getPackageManager().getLaunchIntentForPackage(COM_EXAMPLE_BLEBEACON);

        if (launchIntent != null) {

            startActivity(launchIntent);
        }
    }

    /**
     * This method clears the Beacon Address and Location textboxes.
     */
    public void onClearClick(View view){

        edtBeacon1.setText(R.string.empty_string);

        edtLocation.setText(R.string.empty_string);

        Toast.makeText(this, R.string.text_cleared, Toast.LENGTH_SHORT).show();
    }


    /**
     * This method saves the Beacon Addresses to memory. The addresses are saved to the device
     * when the application exits activity.
     */
    public void onSaveClick(View view){

        BeaconManager.getBeacon().setAddress(edtBeacon1.getText().toString());

        BeaconManager.getBeacon().setLocation(edtLocation.getText().toString());

        Toast.makeText(this, R.string.saved_to_device, Toast.LENGTH_SHORT).show();
    }

    /**
     * Override Back press button to make sure beacons are saved to application
     */
    public void onBackPressed(View view) {

        super.onBackPressed();
    }

    /**
     * Override Destroy method so that the beacons are automatically saved to the device
     */
    @Override
    protected void onDestroy() {
        super.onDestroy();

        if (BeaconManager.getBeacon() != null) {

            SharedPreferences sharedprefs = getApplicationContext().getSharedPreferences(BeaconManager.PREFS_NAME, MODE_PRIVATE);

            BeaconManager.saveBeaconsToDevice(BeaconManager.getBeacon(), sharedprefs);
        }
    }

    /***
     * Set up the event handlers to validate the addresses after they have been made
     */
    private void setOnLeaveEdtBeacon(final EditText edittext) {

        edittext.setOnFocusChangeListener(new View.OnFocusChangeListener() {
            @Override
            public void onFocusChange(View v, boolean hasFocus) {

                String address = ((EditText) v).getText().toString().toUpperCase();

                if (!hasFocus) {

                    if ((!BluetoothAdapter.checkBluetoothAddress(address))) {

                        edittext.setTextColor(getResources().getColor(R.color.colorRed));

                        if (edtBeacon1.length() == 0) {

                            btnSave.setEnabled(false);
                        }

                    } else {

                        edittext.setTextColor(Color.BLACK);

                        btnSave.setEnabled(true);

                        edittext.setText(address);
                    }
                }
            }
        });
    }
}
