/*
 * Copyright(C) Seiko Epson Corporation 2016. All rights reserved.
 *
 * Warranty Disclaimers.
 * You acknowledge and agree that the use of the software is at your own risk.
 * The software is provided "as is" and without any warranty of any kind.
 * Epson and its licensors do not and cannot warrant the performance or results
 * you may obtain by using the software.
 * Epson and its licensors make no warranties, express or implied, as to non-infringement,
 * merchantability or fitness for any particular purpose.
 */

package nmd.emd.epson.com.probt_2000bluetooth;

import android.content.SharedPreferences;
import android.util.Log;

/**
 * Class for managing static instances of the beacon manager
 *
 */
public class BeaconManager {

    // Constants
    private static final String TAG_DEBUG = "Pro BT-2000 Beacon App";
    public static final String PREFS_NAME = "ProBT2000Beacon";
    public static final String BEACON_ADDRESS = "Beacon Address";
    public static final String BEACON_LOCATION = "Beacon Location";

    // Private Variables
    private static Beacon mBeacon = new Beacon(null);

    /**
     * Setter method to set beacons
     * @param beacon
     */
    public static void setmBeacons(Beacon beacon) {
        BeaconManager.mBeacon = beacon;
    }


    /**
     * Getter method to return beacon from memory
     * @return beacon
     */
    public static Beacon getBeacon () {

        if (mBeacon == null)

            Log.d(TAG_DEBUG, "Beacon has not been created");

        return mBeacon;
    }


    /**
     * Method to load beacon addresses which are stored in the device
     *
     * The shared preferences allows you to store primitive types variables.
     * This means you don't have to re-enter the Bluetooth details each time
     * you start the Android device.
     * @param sp
     */
    public static void LoadBeaconsFromDevice(SharedPreferences sp){

        String btAddress = sp.getString(BEACON_ADDRESS, "");

        mBeacon = new Beacon(btAddress);

        mBeacon.setLocation(sp.getString(BEACON_LOCATION, ""));
    }


    /**
     * Method to save beacon to shared preferences in android device
     *
     * The shared preferences allows you to store primitive types variables.
     * This means you don't have to re-enter the Bluetooth details each time
     * you start the Android device.
     *
     * @param beacon
     * @param sharedprefs
     */
    public static void saveBeaconsToDevice (Beacon beacon, SharedPreferences sharedprefs){

        SharedPreferences.Editor editor = sharedprefs.edit();

        editor.putString(BEACON_ADDRESS, beacon.getAddress());

        editor.putString(BEACON_LOCATION, beacon.getLocation());

        // Commit the edits!
        editor.commit();
    }

}





