/*
 * Copyright(C) Seiko Epson Corporation 2016. All rights reserved.
 *
 * Warranty Disclaimers.
 * You acknowledge and agree that the use of the software is at your own risk.
 * The software is provided "as is" and without any warranty of any kind.
 * Epson and its licensors do not and cannot warrant the performance or results
 * you may obtain by using the software.
 * Epson and its licensors make no warranties, express or implied, as to non-infringement,
 * merchantability or fitness for any particular purpose.
 */

package nmd.emd.epson.com.probt_2000bluetooth;

import android.app.Activity;
import android.content.Intent;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.widget.TextView;

import java.text.DateFormat;
import java.util.Date;

public class MainActivity extends Activity {

    private TextView txtViewBeaconStatus;
    private TextView txtStartupTime;

    private static final String PREFS_NAME = "ProBT2000Beacon";
    private static final String BEACON_REGISTERED = "Beacon Registered:";
    private static final String SPACE = " ";
    private static final String NEW_LINE = "\n";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        //Regsiter any UI widgets

        txtViewBeaconStatus = (TextView) findViewById(R.id.txtViewBeaconStatus);

        txtStartupTime = (TextView) findViewById(R.id.txtStartupTime);

        //Retrieve any previosuly registered beacons
        SharedPreferences mSharedPrefs = getSharedPreferences(PREFS_NAME, MODE_PRIVATE);

        //Load the registered beacons into memory
        BeaconManager.LoadBeaconsFromDevice(mSharedPrefs);

        setStatusText();

        //The MOVERIO Pro BT-2000 is based on Android 4.0 Tablet UI. This specification does not
        //normally allow for full application display; however, you can use the following code
        //to enable full display by specifying a unique flag.
//        Window win = getWindow();
//        WindowManager.LayoutParams winParams = win.getAttributes();
//        winParams.flags |= winParams.flags |= 0x80000000;
//        win.setAttributes(winParams);

        String currentDateTimeString = DateFormat.getDateTimeInstance().format(new Date());

        txtStartupTime.setText(String.format(getString(R.string.startup_time), currentDateTimeString));

    }

    private void setStatusText() {
        if (BeaconManager.getBeacon().getAddress().equals("")){

            txtViewBeaconStatus.setTextColor(Color.RED);

            txtViewBeaconStatus.setText(R.string.no_beacon_configured);

        } else {

            txtViewBeaconStatus.setTextColor(Color.BLACK);

            StringBuilder beacaonStatus = new StringBuilder();

            beacaonStatus.append("Location: \t").append(BeaconManager.getBeacon().getLocation()).append(NEW_LINE);
            beacaonStatus.append("Address: \t\t").append(BeaconManager.getBeacon().getAddress());

            txtViewBeaconStatus.setText(beacaonStatus);

        }
    }

    /**
     * OnClick button to launch register beacons page
     */
    public void onBeaconRegisterClick (View view){

        Intent registerBeaconIntent = new Intent(MainActivity.this, BeaconActivity.class);

        MainActivity.this.startActivity(registerBeaconIntent);
    }

    /**
     * OnClick button to open up the example plan page
     */
    public void onContinueClick (View view){

        Intent continueIntent = new Intent(MainActivity.this, PlanActivity.class);

        MainActivity.this.startActivity(continueIntent);
    }

    /**
     * Button on click code to restart the demo and display the splash screen
     *
     * @param view
     */
    public void onClickRestart(View view) {

        Intent i = getBaseContext().getPackageManager()
                .getLaunchIntentForPackage(getBaseContext().getPackageName());

        i.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);

        startActivity(i);
    }

    @Override
    protected void onResume() {
        super.onResume();

        setStatusText();
    }
}

