/*
 * Copyright(C) Seiko Epson Corporation 2016. All rights reserved.
 *
 * Warranty Disclaimers.
 * You acknowledge and agree that the use of the software is at your own risk.
 * The software is provided "as is" and without any warranty of any kind.
 * Epson and its licensors do not and cannot warrant the performance or results
 * you may obtain by using the software.
 * Epson and its licensors make no warranties, express or implied, as to non-infringement,
 * merchantability or fitness for any particular purpose.
 */

package nmd.emd.epson.com.probt_2000bluetooth;

import android.app.Activity;
import android.bluetooth.BluetoothLeAdapterManager;
import android.bluetooth.BluetoothLeGapCallback;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

public class PlanActivity extends Activity {


    private String mRegisteredAddress;
    private volatile ImageView mImgBeaconStrength;
    private TextView mTxtLocation;
    private TextView mAdditionalInfo;
    private RelativeLayout mPlan;
    private Button mBtnShowFloorPlan;
    private ImageView mLocatorImage;
    private static int mConnectAttempts = 20;

    private BluetoothLeAdapterManager mManager;
    private BluetoothLeGapCallback mLeGapCallback;
    private BLEStrength mCurrentBleStrength = BLEStrength.Unknown;
    private boolean mIsFirstDetect = true;
    private boolean mIsPlanShown = true;

    BLEStrength mNewBleStrength;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        Log.d("EPSON", "Create");

        setContentView(R.layout.activity_plan);

        mTxtLocation = (TextView) findViewById(R.id.txtLocation);

        mAdditionalInfo = (TextView) findViewById(R.id.txtAdditionalInfo);

        mTxtLocation.setText(BeaconManager.getBeacon().getLocation());

        mPlan = (RelativeLayout) findViewById(R.id.rlPlan);

        mBtnShowFloorPlan = (Button) findViewById(R.id.btnShowFloorPlan);

        mBtnShowFloorPlan.clearFocus();

        mLocatorImage = (ImageView) findViewById(R.id.ivLocator);

        mLocatorImage.setVisibility(View.GONE);

        mImgBeaconStrength = (ImageView) findViewById(R.id.imgBeaconStrength);

        startBluetoothDetection();
    }

    /**
     * Method to initialisze bluetooth le and start detection.
     */
    private void startBluetoothDetection(){

        //Instance acquisition for the BLE manager class
        this.mManager = BluetoothLeAdapterManager.getInstance();


        //Provide an interface for the callback function to receive scan results (Advertise data).
        this.mLeGapCallback = new BluetoothLeGapCallback() {
            @Override
            public void onScanResult(AddrType addrType, String addr, int rssi, boolean scan_rsp, AdvType adv_type, byte[] adv_data) {

                //Get the current Beacon Address in lowercase
                mRegisteredAddress = BeaconManager.getBeacon().getAddress().toLowerCase();

                //Compare to any other beacons in the vicinity. This example only uses one registered beacon
                if (mRegisteredAddress.equals(addr)) {

                    mConnectAttempts = 20;

                    if (mCurrentBleStrength != detectBecaonStrengthRange(rssi)) {

                        mCurrentBleStrength = detectBecaonStrengthRange(rssi);

                        runOnUiThread(new Runnable() {

                            @Override
                            public void run() {

                                setImageStrength(mCurrentBleStrength);

                                mAdditionalInfo.setText(R.string.info_beacon);
                            }
                        });

                    } else {

                        mConnectAttempts --;

                        if (mConnectAttempts == 0) {

                            mImgBeaconStrength.setImageResource(R.drawable.no_connection_48);

                            mAdditionalInfo.setText(R.string.info_no_beacon);
                        }
                    }

                    int currentRSSI = BeaconManager.getBeacon().getRSSI();
                    BeaconManager.getBeacon().setmRSSI(rssi);

                    try {
                        Thread.sleep(3000);
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                } else {
                    runOnUiThread(new Runnable() {

                        @Override
                        public void run() {

                            mConnectAttempts --;

                            if (mConnectAttempts == 0) {

                                mImgBeaconStrength.setImageResource(R.drawable.no_connection_48);

                                mAdditionalInfo.setText(R.string.info_no_beacon);
                            }
                        }
                    });
                }
            }
        };

        //Register a callback for the GAP function provided
        mManager.setGapCallback(mLeGapCallback);

        //Enable BLE
        mManager.enable();

        //Start the BLE scan (Advertise reception)
        this.mManager.startScan();

        mAdditionalInfo.setText(R.string.info_no_beacon);

    }

    /**
     * Method to shutdown beacon scanning
     */
    private void stopBluetoothDetection(){

        mManager.stopScan();

        mManager.disable();
    }


    /**
     * Derive the distance in human readable form
     * @param rssi
     * @return
     */
    private BLEStrength detectBecaonStrengthRange(int rssi){

        rssi = Math.abs(rssi);

        BLEStrength bleStrength;


        if (rssi <= 60 ) {

            bleStrength = BLEStrength.Near;

        } else if ((rssi >= 60) && (rssi <= 75)) {

            bleStrength = BLEStrength.Intermediate;


        } else if ((rssi > 75) && (rssi <= 100)) {

            bleStrength = BLEStrength.Far;

        } else {

            bleStrength = BLEStrength.Unknown;
            mLocatorImage.setVisibility(View.GONE);
        }

        return bleStrength;
    }


    /**
     * Pirvate method to set the correct signal strangth image
     * @param bleStrength
     */
    private  void setImageStrength(final BLEStrength bleStrength) {

        switch (bleStrength) {

            case Near :
                mImgBeaconStrength.setImageResource(R.drawable.high_connection48);

                mLocatorImage.setImageResource(R.drawable.circle_thin_small);

                mLocatorImage.setVisibility(View.VISIBLE);

                break;

            case Intermediate :
                mImgBeaconStrength.setImageResource(R.drawable.medium_connection48);

                mLocatorImage.setImageResource(R.drawable.circle_thin_medium);

                mLocatorImage.setVisibility(View.VISIBLE);

                break;

            case Far :
                mImgBeaconStrength.setImageResource(R.drawable.low_connection48);

                mLocatorImage.setImageResource(R.drawable.circle_thin_large);

                mLocatorImage.setVisibility(View.VISIBLE);

                break;

            default :

                mImgBeaconStrength.setImageResource(R.drawable.no_connection_48);
        }
    }

    /**
     * Button onClick Method
     * @param view
     */
    public void TogglePlan(View view){

        if (mIsPlanShown == true){

            mIsPlanShown = false;

            mPlan.setVisibility(View.GONE);

            mBtnShowFloorPlan.setText(nmd.emd.epson.com.probt_2000bluetooth.R.string.btn_show_plan);

        } else {

            mIsPlanShown = true;

            mPlan.setVisibility(View.VISIBLE);

            mBtnShowFloorPlan.setText(nmd.emd.epson.com.probt_2000bluetooth.R.string.btn_close_plan1);
        }

    }



    @Override
    protected void onResume() {
        super.onResume();
        Log.d("EPSON", "Resume");
        startBluetoothDetection();
    }

    @Override
    protected void onPause() {
        super.onPause();
        Log.d("EPSON", "Pause");
        stopBluetoothDetection();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        Log.d("EPSON", "Destroy");
        stopBluetoothDetection();
    }

    @Override
    protected void onStop() {
        super.onStop();
        Log.d("EPSON", "Stop");
        stopBluetoothDetection();
    }
}
